SPECIAL_CHARS_REGEX top-level property

Pattern SPECIAL_CHARS_REGEX
final

Pattern matching the regex metacharacters that have to be escaped before a search pattern can safely be compiled as a RegExp.

Implementation

final Pattern SPECIAL_CHARS_REGEX = RegExp(r'[-\[\]/{}()*+?.\\^$|]');