ResultDetails<T> class

Details of a result.

Constructors

ResultDetails({String key = '', required int arrayIndex, required String value, required double score, required List<MatchIndex> matchedIndices, double nScore = 0})
Instantiates it

Properties

arrayIndex → int
Index of result in the original list
final
hashCode → int
The hash code for this object.
no setterinherited
key → String
Key (WeightedKey.name) used to create this
final
matchedIndices → List<MatchIndex>
Indexes of matched patterns on the value
final
nScore ↔ double
nScore of this result. It's the weighted score of the match, when it's a weighted search (i.e. uses WeightedKeys).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → double
Score of this result
final
value → String
Original value
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited